==> igniteui-angular-core-19.0.1.tgz: package/esm2015/lib/WebCarouselDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebNumberEventArgsDescriptionMetadata } from "./WebNumberEventArgsDescriptionMetadata";
import { VoidEventArgsDescriptionMetadata } from "./VoidEventArgsDescriptionMetadata";
import { WebCarouselDescription } from "./WebCarouselDescription";
/**
 * @hidden
 */
export let WebCarouselDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebCarouselDescriptionMetadata extends Base {
        static b(a) {
            if (WebCarouselDescriptionMetadata.a == null) {
                WebCarouselDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebCarouselDescriptionMetadata.c(WebCarouselDescriptionMetadata.a);
            }
            if (a.k(WebCarouselDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebCarouselDescriptionMetadata.a);
            WebNumberEventArgsDescriptionMetadata.d(a);
            VoidEventArgsDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:Carousel");
            a.item("__tagNameWC", "String:igc-carousel");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("DisableLoop", "Boolean");
            a.item("DisablePauseOnInteraction", "Boolean");
            a.item("HideNavigation", "Boolean");
            a.item("HideIndicators", "Boolean");
            a.item("Vertical", "Boolean");
            a.item("IndicatorsOrientation", "ExportedType:string:CarouselIndicatorsOrientation");
            a.item("IndicatorsOrientation@stringUnion", "WebComponents;React");
            a.item("IndicatorsOrientation@names", "End;Start");
            a.item("IndicatorsLabelFormat", "String");
            a.item("SlidesLabelFormat", "String");
            a.item("Interval", "Number:double");
            a.item("MaximumIndicatorsCount", "Number:double");
            a.item("AnimationType", "ExportedType:string:CarouselAnimationType");
            a.item("AnimationType@stringUnion", "WebComponents;React");
            a.item("AnimationType@names", "Slide;Fade;None");
            a.item("SlideChangedRef", "EventRef::slideChanged");
            a.item("PlayingRef", "EventRef::playing");
            a.item("PausedRef", "EventRef::paused");
        }
        static d(a) {
            WebCarouselDescriptionMetadata.b(a);
            a.ae("WebCarousel", () => new WebCarouselDescription());
            a.ad("WebCarousel", WebCarouselDescriptionMetadata.a);
        }
    }
    WebCarouselDescriptionMetadata.$t = markType(WebCarouselDescriptionMetadata, 'WebCarouselDescriptionMetadata');
    WebCarouselDescriptionMetadata.a = null;
    return WebCarouselDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/WebCarouselDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebNumberEventArgsDescriptionMetadata } from "./WebNumberEventArgsDescriptionMetadata";
import { VoidEventArgsDescriptionMetadata } from "./VoidEventArgsDescriptionMetadata";
import { WebCarouselDescription } from "./WebCarouselDescription";
/**
 * @hidden
 */
export let WebCarouselDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebCarouselDescriptionMetadata extends Base {
        static b(a) {
            if (WebCarouselDescriptionMetadata.a == null) {
                WebCarouselDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebCarouselDescriptionMetadata.c(WebCarouselDescriptionMetadata.a);
            }
            if (a.k(WebCarouselDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebCarouselDescriptionMetadata.a);
            WebNumberEventArgsDescriptionMetadata.d(a);
            VoidEventArgsDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:Carousel");
            a.item("__tagNameWC", "String:igc-carousel");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("DisableLoop", "Boolean");
            a.item("DisablePauseOnInteraction", "Boolean");
            a.item("HideNavigation", "Boolean");
            a.item("HideIndicators", "Boolean");
            a.item("Vertical", "Boolean");
            a.item("IndicatorsOrientation", "ExportedType:string:CarouselIndicatorsOrientation");
            a.item("IndicatorsOrientation@stringUnion", "WebComponents;React");
            a.item("IndicatorsOrientation@names", "End;Start");
            a.item("IndicatorsLabelFormat", "String");
            a.item("SlidesLabelFormat", "String");
            a.item("Interval", "Number:double");
            a.item("MaximumIndicatorsCount", "Number:double");
            a.item("AnimationType", "ExportedType:string:HorizontalTransitionAnimation");
            a.item("AnimationType@stringUnion", "WebComponents;React");
            a.item("AnimationType@names", "Slide;Fade;None");
            a.item("SlideChangedRef", "EventRef::slideChanged");
            a.item("PlayingRef", "EventRef::playing");
            a.item("PausedRef", "EventRef::paused");
        }
        static d(a) {
            WebCarouselDescriptionMetadata.b(a);
            a.ae("WebCarousel", () => new WebCarouselDescription());
            a.ad("WebCarousel", WebCarouselDescriptionMetadata.a);
        }
    }
    WebCarouselDescriptionMetadata.$t = markType(WebCarouselDescriptionMetadata, 'WebCarouselDescriptionMetadata');
    WebCarouselDescriptionMetadata.a = null;
    return WebCarouselDescriptionMetadata;
})();
